@@ -1,10 +1,10 @@
 # @package      hubzero-submit-distributor
 # @file         RemoteBatchPBS8.py
 # @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -27,6 +27,7 @@
 
 import os.path
 import re
+import logging
 
 from hubzero.submit.TimeConversion import minTohhmmss
 
@@ -51,6 +52,7 @@ class RemoteBatchPBS8:
                 wallTime,
                 quotaLimit,
                 timeHistoryLogs):
+      self.logger              = logging.getLogger(__name__)
       self.hubUserName         = hubUserName
       self.hubUserId           = hubUserId
       self.runName             = runName
@@ -147,7 +149,7 @@ QUOTA
 date +"%s" > TS_START
 
 PREMANAGERCOMMANDS
-${TIMEPATH} -p -o TIME_RESULTS EXECUTABLE ARGUMENTS STDIN > RUNNAME_INSTANCEID.stdout 2> RUNNAME_INSTANCEID.stderr
+${TIMEPATH} --format "Command exited with status %x\\nreal %e\\nuser %U\\nsys %S" -o TIME_RESULTS EXECUTABLE ARGUMENTS STDIN > RUNNAME_INSTANCEID.stdout 2> RUNNAME_INSTANCEID.stderr
 POSTMANAGERCOMMANDS
 
 date +"%s" > TS_FINISH
@@ -267,7 +269,7 @@ for timePath in ${HOME}/bin/time /usr/bin/time /usr/local/bin/time /apps/submit/
    fi
 done
 
-export TIMERCOMMAND="${TIMEPATH} -p -a -o TIME_RESULTS"
+export TIMERCOMMAND="${TIMEPATH} --format "Command exited with status %x\\nreal %e\\nuser %U\\nsys %S" -a -o TIME_RESULTS"
 
 QUOTA
 
@@ -402,7 +404,7 @@ QUOTA
 date +"%s" > TS_START
 
 PREMANAGERCOMMANDS
-${TIMEPATH} -p -o TIME_RESULTS MANAGERCOMMAND ${APPLICATION} ARGUMENTS STDIN > RUNNAME_INSTANCEID.stdout 2> RUNNAME_INSTANCEID.stderr
+${TIMEPATH} --format "Command exited with status %x\\nreal %e\\nuser %U\\nsys %S" -o TIME_RESULTS MANAGERCOMMAND ${APPLICATION} ARGUMENTS STDIN > RUNNAME_INSTANCEID.stdout 2> RUNNAME_INSTANCEID.stderr
 POSTMANAGERCOMMANDS
 
 date +"%s" > TS_FINISH
